@@ -1,9 +1,9 @@
-from typing import Union, Dict, Type, Callable, Any, TYPE_CHECKING
+from typing import TYPE_CHECKING, Any, Callable, Dict, Type, Union
+
 from .enums import GroupEventType, UserEventType
 
-
 if TYPE_CHECKING:
-    from .typings import GroupTypes, UserTypes
+    from . import GroupTypes, UserTypes
     from .bot_events import BaseGroupEvent
     from .user_events import BaseUserEvent
 
