@@ -1,14 +1,14 @@
-from vkbottle_types.responses import gifts
-from typing import Optional, Any, List
+import typing
 from .base_category import BaseCategory
+from vkbottle_types.responses import gifts
 
 
 class GiftsCategory(BaseCategory):
     async def get(
         self,
-        user_id: Optional[int] = None,
-        count: Optional[int] = None,
-        offset: Optional[int] = None,
+        user_id: typing.Optional[int] = None,
+        count: typing.Optional[int] = None,
+        offset: typing.Optional[int] = None,
         **kwargs
     ) -> gifts.GetResponseModel:
         """Returns a list of user gifts.
