@@ -1,14 +1,14 @@
-from vkbottle_types.responses import messages, base
-from typing import Optional, Any, List
+import typing
 from .base_category import BaseCategory
+from vkbottle_types.responses import base, messages
 
 
 class MessagesCategory(BaseCategory):
     async def add_chat_user(
         self,
         chat_id: int,
-        user_id: Optional[int] = None,
-        visible_messages_count: Optional[int] = None,
+        user_id: typing.Optional[int] = None,
+        visible_messages_count: typing.Optional[int] = None,
         **kwargs
     ) -> base.OkResponseModel:
         """Adds a new user to a chat.
@@ -23,7 +23,7 @@ class MessagesCategory(BaseCategory):
         return model(**response).response
 
     async def allow_messages_from_group(
-        self, group_id: int, key: Optional[str] = None, **kwargs
+        self, group_id: int, key: typing.Optional[str] = None, **kwargs
     ) -> base.OkResponseModel:
         """Allows sending messages from community to the current user.
         :param group_id: Group ID.
@@ -37,9 +37,9 @@ class MessagesCategory(BaseCategory):
 
     async def create_chat(
         self,
-        user_ids: Optional[List[int]] = None,
-        title: Optional[str] = None,
-        group_id: Optional[int] = None,
+        user_ids: typing.Optional[typing.List[int]] = None,
+        title: typing.Optional[str] = None,
+        group_id: typing.Optional[int] = None,
         **kwargs
     ) -> messages.CreateChatResponseModel:
         """Creates a chat with several participants.
@@ -55,10 +55,12 @@ class MessagesCategory(BaseCategory):
 
     async def delete(
         self,
-        message_ids: Optional[List[int]] = None,
-        spam: Optional[bool] = None,
-        group_id: Optional[int] = None,
-        delete_for_all: Optional[bool] = None,
+        message_ids: typing.Optional[typing.List[int]] = None,
+        spam: typing.Optional[bool] = None,
+        group_id: typing.Optional[int] = None,
+        delete_for_all: typing.Optional[bool] = None,
+        peer_id: typing.Optional[int] = None,
+        conversation_message_ids: typing.Optional[typing.List[int]] = None,
         **kwargs
     ) -> messages.DeleteResponseModel:
         """Deletes one or more messages.
@@ -66,6 +68,8 @@ class MessagesCategory(BaseCategory):
         :param spam: '1' — to mark message as spam.
         :param group_id: Group ID (for group messages with user access token)
         :param delete_for_all: '1' — delete message for for all.
+        :param peer_id: Destination ID. "For user: 'User ID', e.g. '12345'. For chat: '2000000000' + 'chat_id', e.g. '2000000001'. For community: '- community ID', e.g. '-12345'. "
+        :param conversation_message_ids: Conversation message IDs.
         """
 
         params = self.get_set_params(locals())
@@ -74,7 +78,7 @@ class MessagesCategory(BaseCategory):
         return model(**response).response
 
     async def delete_chat_photo(
-        self, chat_id: int, group_id: Optional[int] = None, **kwargs
+        self, chat_id: int, group_id: typing.Optional[int] = None, **kwargs
     ) -> messages.DeleteChatPhotoResponseModel:
         """Deletes a chat's cover picture.
         :param chat_id: Chat ID.
@@ -88,9 +92,9 @@ class MessagesCategory(BaseCategory):
 
     async def delete_conversation(
         self,
-        user_id: Optional[int] = None,
-        peer_id: Optional[int] = None,
-        group_id: Optional[int] = None,
+        user_id: typing.Optional[int] = None,
+        peer_id: typing.Optional[int] = None,
+        group_id: typing.Optional[int] = None,
         **kwargs
     ) -> messages.DeleteConversationResponseModel:
         """Deletes all private messages in a conversation.
@@ -119,18 +123,18 @@ class MessagesCategory(BaseCategory):
     async def edit(
         self,
         peer_id: int,
-        message: Optional[str] = None,
-        lat: Optional[float] = None,
-        long: Optional[float] = None,
-        attachment: Optional[str] = None,
-        keep_forward_messages: Optional[bool] = None,
-        keep_snippets: Optional[bool] = None,
-        group_id: Optional[int] = None,
-        dont_parse_links: Optional[bool] = None,
-        message_id: Optional[int] = None,
-        conversation_message_id: Optional[int] = None,
-        template: Optional[str] = None,
-        keyboard: Optional[str] = None,
+        message: typing.Optional[str] = None,
+        lat: typing.Optional[int] = None,
+        long: typing.Optional[int] = None,
+        attachment: typing.Optional[str] = None,
+        keep_forward_messages: typing.Optional[bool] = None,
+        keep_snippets: typing.Optional[bool] = None,
+        group_id: typing.Optional[int] = None,
+        dont_parse_links: typing.Optional[bool] = None,
+        message_id: typing.Optional[int] = None,
+        conversation_message_id: typing.Optional[int] = None,
+        template: typing.Optional[str] = None,
+        keyboard: typing.Optional[str] = None,
         **kwargs
     ) -> messages.EditResponseModel:
         """Edits the message.
@@ -155,7 +159,7 @@ class MessagesCategory(BaseCategory):
         return model(**response).response
 
     async def edit_chat(
-        self, chat_id: int, title: Optional[str] = None, **kwargs
+        self, chat_id: int, title: typing.Optional[str] = None, **kwargs
     ) -> base.OkResponseModel:
         """Edits the title of a chat.
         :param chat_id: Chat ID.
@@ -170,10 +174,10 @@ class MessagesCategory(BaseCategory):
     async def get_by_conversation_message_id(
         self,
         peer_id: int,
-        conversation_message_ids: List[int],
-        extended: Optional[bool] = None,
-        fields: Optional[List[str]] = None,
-        group_id: Optional[int] = None,
+        conversation_message_ids: typing.List[int],
+        extended: typing.Optional[bool] = None,
+        fields: typing.Optional[typing.List[str]] = None,
+        group_id: typing.Optional[int] = None,
         **kwargs
     ) -> messages.GetByConversationMessageIdResponseModel:
         """Returns messages by their IDs within the conversation.
@@ -191,11 +195,11 @@ class MessagesCategory(BaseCategory):
 
     async def get_by_id(
         self,
-        message_ids: List[int],
-        preview_length: Optional[int] = None,
-        extended: Optional[bool] = None,
-        fields: Optional[List[str]] = None,
-        group_id: Optional[int] = None,
+        message_ids: typing.List[int],
+        preview_length: typing.Optional[int] = None,
+        extended: typing.Optional[bool] = None,
+        fields: typing.Optional[typing.List[str]] = None,
+        group_id: typing.Optional[int] = None,
         **kwargs
     ) -> messages.GetByIdResponseModel:
         """Returns messages by their IDs.
@@ -217,9 +221,9 @@ class MessagesCategory(BaseCategory):
 
     async def get_chat_preview(
         self,
-        peer_id: Optional[int] = None,
-        link: Optional[str] = None,
-        fields: Optional[List[str]] = None,
+        peer_id: typing.Optional[int] = None,
+        link: typing.Optional[str] = None,
+        fields: typing.Optional[typing.List[str]] = None,
         **kwargs
     ) -> messages.GetChatPreviewResponseModel:
         """messages.getChatPreview method
@@ -236,8 +240,8 @@ class MessagesCategory(BaseCategory):
     async def get_conversation_members(
         self,
         peer_id: int,
-        fields: Optional[List[str]] = None,
-        group_id: Optional[int] = None,
+        fields: typing.Optional[typing.List[str]] = None,
+        group_id: typing.Optional[int] = None,
         **kwargs
     ) -> messages.GetConversationMembersResponseModel:
         """Returns a list of IDs of users participating in a chat.
@@ -253,13 +257,13 @@ class MessagesCategory(BaseCategory):
 
     async def get_conversations(
         self,
-        offset: Optional[int] = None,
-        count: Optional[int] = None,
-        filter: Optional[str] = None,
-        extended: Optional[bool] = None,
-        start_message_id: Optional[int] = None,
-        fields: Optional[List[str]] = None,
-        group_id: Optional[int] = None,
+        offset: typing.Optional[int] = None,
+        count: typing.Optional[int] = None,
+        filter: typing.Optional[str] = None,
+        extended: typing.Optional[bool] = None,
+        start_message_id: typing.Optional[int] = None,
+        fields: typing.Optional[typing.List[str]] = None,
+        group_id: typing.Optional[int] = None,
         **kwargs
     ) -> messages.GetConversationsResponseModel:
         """Returns a list of the current user's conversations.
@@ -279,10 +283,10 @@ class MessagesCategory(BaseCategory):
 
     async def get_conversations_by_id(
         self,
-        peer_ids: List[int],
-        extended: Optional[bool] = None,
-        fields: Optional[List[str]] = None,
-        group_id: Optional[int] = None,
+        peer_ids: typing.List[int],
+        extended: typing.Optional[bool] = None,
+        fields: typing.Optional[typing.List[str]] = None,
+        group_id: typing.Optional[int] = None,
         **kwargs
     ) -> messages.GetConversationsByIdResponseModel:
         """Returns conversations by their IDs
@@ -303,15 +307,15 @@ class MessagesCategory(BaseCategory):
 
     async def get_history(
         self,
-        offset: Optional[int] = None,
-        count: Optional[int] = None,
-        user_id: Optional[int] = None,
-        peer_id: Optional[int] = None,
-        start_message_id: Optional[int] = None,
-        rev: Optional[int] = None,
-        extended: Optional[bool] = None,
-        fields: Optional[List[str]] = None,
-        group_id: Optional[int] = None,
+        offset: typing.Optional[int] = None,
+        count: typing.Optional[int] = None,
+        user_id: typing.Optional[int] = None,
+        peer_id: typing.Optional[int] = None,
+        start_message_id: typing.Optional[int] = None,
+        rev: typing.Optional[int] = None,
+        extended: typing.Optional[bool] = None,
+        fields: typing.Optional[typing.List[str]] = None,
+        group_id: typing.Optional[int] = None,
         **kwargs
     ) -> messages.GetHistoryResponseModel:
         """Returns message history for the specified user or group chat.
@@ -328,20 +332,24 @@ class MessagesCategory(BaseCategory):
 
         params = self.get_set_params(locals())
         response = await self.api.request("messages.getHistory", params)
-        model = messages.GetHistoryResponse
+        model = self.get_model(
+            {("extended",): messages.GetHistoryExtendedResponse},
+            default=messages.GetHistoryResponse,
+            params=params,
+        )
         return model(**response).response
 
     async def get_history_attachments(
         self,
         peer_id: int,
-        media_type: Optional[str] = None,
-        start_from: Optional[str] = None,
-        count: Optional[int] = None,
-        photo_sizes: Optional[bool] = None,
-        fields: Optional[List[str]] = None,
-        group_id: Optional[int] = None,
-        preserve_order: Optional[bool] = None,
-        max_forwards_level: Optional[int] = None,
+        media_type: typing.Optional[str] = None,
+        start_from: typing.Optional[str] = None,
+        count: typing.Optional[int] = None,
+        photo_sizes: typing.Optional[bool] = None,
+        fields: typing.Optional[typing.List[str]] = None,
+        group_id: typing.Optional[int] = None,
+        preserve_order: typing.Optional[bool] = None,
+        max_forwards_level: typing.Optional[int] = None,
         **kwargs
     ) -> messages.GetHistoryAttachmentsResponseModel:
         """Returns media files from the dialog or group chat.
@@ -361,11 +369,67 @@ class MessagesCategory(BaseCategory):
         model = messages.GetHistoryAttachmentsResponse
         return model(**response).response
 
+    async def get_important_messages(
+        self,
+        count: typing.Optional[int] = None,
+        offset: typing.Optional[int] = None,
+        start_message_id: typing.Optional[int] = None,
+        preview_length: typing.Optional[int] = None,
+        fields: typing.Optional[typing.List[str]] = None,
+        extended: typing.Optional[bool] = None,
+        group_id: typing.Optional[int] = None,
+        **kwargs
+    ) -> messages.GetImportantMessagesResponseModel:
+        """Returns a list of user's important messages.
+        :param count: Amount of needed important messages.
+        :param offset:
+        :param start_message_id:
+        :param preview_length: Maximum length of messages body.
+        :param fields: Actors fields to return.
+        :param extended: Return extended properties
+        :param group_id: Group ID (for group messages with group access token)
+        """
+
+        params = self.get_set_params(locals())
+        response = await self.api.request("messages.getImportantMessages", params)
+        model = self.get_model(
+            {("extended",): messages.GetImportantMessagesExtendedResponse},
+            default=messages.GetImportantMessagesResponse,
+            params=params,
+        )
+        return model(**response).response
+
+    async def get_intent_users(
+        self,
+        intent: str,
+        subscribe_id: typing.Optional[int] = None,
+        offset: typing.Optional[int] = None,
+        count: typing.Optional[int] = None,
+        extended: typing.Optional[bool] = None,
+        name_case: typing.Optional[typing.List[str]] = None,
+        fields: typing.Optional[typing.List[str]] = None,
+        **kwargs
+    ) -> messages.GetIntentUsersResponseModel:
+        """messages.getIntentUsers method
+        :param intent:
+        :param subscribe_id:
+        :param offset:
+        :param count:
+        :param extended:
+        :param name_case:
+        :param fields:
+        """
+
+        params = self.get_set_params(locals())
+        response = await self.api.request("messages.getIntentUsers", params)
+        model = messages.GetIntentUsersResponse
+        return model(**response).response
+
     async def get_invite_link(
         self,
         peer_id: int,
-        reset: Optional[bool] = None,
-        group_id: Optional[int] = None,
+        reset: typing.Optional[bool] = None,
+        group_id: typing.Optional[int] = None,
         **kwargs
     ) -> messages.GetInviteLinkResponseModel:
         """messages.getInviteLink method
@@ -393,18 +457,18 @@ class MessagesCategory(BaseCategory):
 
     async def get_long_poll_history(
         self,
-        ts: Optional[int] = None,
-        pts: Optional[int] = None,
-        preview_length: Optional[int] = None,
-        onlines: Optional[bool] = None,
-        fields: Optional[List[str]] = None,
-        events_limit: Optional[int] = None,
-        msgs_limit: Optional[int] = None,
-        max_msg_id: Optional[int] = None,
-        group_id: Optional[int] = None,
-        lp_version: Optional[int] = None,
-        last_n: Optional[int] = None,
-        credentials: Optional[bool] = None,
+        ts: typing.Optional[int] = None,
+        pts: typing.Optional[int] = None,
+        preview_length: typing.Optional[int] = None,
+        onlines: typing.Optional[bool] = None,
+        fields: typing.Optional[typing.List[str]] = None,
+        events_limit: typing.Optional[int] = None,
+        msgs_limit: typing.Optional[int] = None,
+        max_msg_id: typing.Optional[int] = None,
+        group_id: typing.Optional[int] = None,
+        lp_version: typing.Optional[int] = None,
+        last_n: typing.Optional[int] = None,
+        credentials: typing.Optional[bool] = None,
         **kwargs
     ) -> messages.GetLongPollHistoryResponseModel:
         """Returns updates in user's private messages.
@@ -429,9 +493,9 @@ class MessagesCategory(BaseCategory):
 
     async def get_long_poll_server(
         self,
-        need_pts: Optional[bool] = None,
-        group_id: Optional[int] = None,
-        lp_version: Optional[int] = None,
+        need_pts: typing.Optional[bool] = None,
+        group_id: typing.Optional[int] = None,
+        lp_version: typing.Optional[int] = None,
         **kwargs
     ) -> messages.GetLongPollServerResponseModel:
         """Returns data required for connection to a Long Poll server.
@@ -473,8 +537,8 @@ class MessagesCategory(BaseCategory):
     async def mark_as_answered_conversation(
         self,
         peer_id: int,
-        answered: Optional[bool] = None,
-        group_id: Optional[int] = None,
+        answered: typing.Optional[bool] = None,
+        group_id: typing.Optional[int] = None,
         **kwargs
     ) -> base.OkResponseModel:
         """Marks and unmarks conversations as unanswered.
@@ -490,8 +554,8 @@ class MessagesCategory(BaseCategory):
 
     async def mark_as_important(
         self,
-        message_ids: Optional[List[int]] = None,
-        important: Optional[int] = None,
+        message_ids: typing.Optional[typing.List[int]] = None,
+        important: typing.Optional[int] = None,
         **kwargs
     ) -> messages.MarkAsImportantResponseModel:
         """Marks and unmarks messages as important (starred).
@@ -507,8 +571,8 @@ class MessagesCategory(BaseCategory):
     async def mark_as_important_conversation(
         self,
         peer_id: int,
-        important: Optional[bool] = None,
-        group_id: Optional[int] = None,
+        important: typing.Optional[bool] = None,
+        group_id: typing.Optional[int] = None,
         **kwargs
     ) -> base.OkResponseModel:
         """Marks and unmarks conversations as important.
@@ -518,19 +582,17 @@ class MessagesCategory(BaseCategory):
         """
 
         params = self.get_set_params(locals())
-        response = await self.api.request(
-            "messages.markAsImportantConversation", params
-        )
+        response = await self.api.request("messages.markAsImportantConversation", params)
         model = base.OkResponse
         return model(**response).response
 
     async def mark_as_read(
         self,
-        message_ids: Optional[List[int]] = None,
-        peer_id: Optional[int] = None,
-        start_message_id: Optional[int] = None,
-        group_id: Optional[int] = None,
-        mark_conversation_as_read: Optional[bool] = None,
+        message_ids: typing.Optional[typing.List[int]] = None,
+        peer_id: typing.Optional[int] = None,
+        start_message_id: typing.Optional[int] = None,
+        group_id: typing.Optional[int] = None,
+        mark_conversation_as_read: typing.Optional[bool] = None,
         **kwargs
     ) -> base.OkResponseModel:
         """Marks messages as read.
@@ -547,11 +609,16 @@ class MessagesCategory(BaseCategory):
         return model(**response).response
 
     async def pin(
-        self, peer_id: int, message_id: Optional[int] = None, **kwargs
+        self,
+        peer_id: int,
+        message_id: typing.Optional[int] = None,
+        conversation_message_id: typing.Optional[int] = None,
+        **kwargs
     ) -> messages.PinResponseModel:
         """Pin a message.
         :param peer_id: Destination ID. "For user: 'User ID', e.g. '12345'. For chat: '2000000000' + 'Chat ID', e.g. '2000000001'. For community: '- Community ID', e.g. '-12345'. "
-        :param message_id:
+        :param message_id: Message ID
+        :param conversation_message_id: Conversation message ID
         """
 
         params = self.get_set_params(locals())
@@ -562,8 +629,8 @@ class MessagesCategory(BaseCategory):
     async def remove_chat_user(
         self,
         chat_id: int,
-        user_id: Optional[int] = None,
-        member_id: Optional[int] = None,
+        user_id: typing.Optional[int] = None,
+        member_id: typing.Optional[int] = None,
         **kwargs
     ) -> base.OkResponseModel:
         """Allows the current user to leave a chat or, if the current user started the chat, allows the user to remove another user from the chat.
@@ -578,7 +645,7 @@ class MessagesCategory(BaseCategory):
         return model(**response).response
 
     async def restore(
-        self, message_id: int, group_id: Optional[int] = None, **kwargs
+        self, message_id: int, group_id: typing.Optional[int] = None, **kwargs
     ) -> base.OkResponseModel:
         """Restores a deleted message.
         :param message_id: ID of a previously-deleted message to restore.
@@ -592,15 +659,15 @@ class MessagesCategory(BaseCategory):
 
     async def search(
         self,
-        q: Optional[str] = None,
-        peer_id: Optional[int] = None,
-        date: Optional[int] = None,
-        preview_length: Optional[int] = None,
-        offset: Optional[int] = None,
-        count: Optional[int] = None,
-        extended: Optional[bool] = None,
-        fields: Optional[List[str]] = None,
-        group_id: Optional[int] = None,
+        q: typing.Optional[str] = None,
+        peer_id: typing.Optional[int] = None,
+        date: typing.Optional[int] = None,
+        preview_length: typing.Optional[int] = None,
+        offset: typing.Optional[int] = None,
+        count: typing.Optional[int] = None,
+        extended: typing.Optional[bool] = None,
+        fields: typing.Optional[typing.List[str]] = None,
+        group_id: typing.Optional[int] = None,
         **kwargs
     ) -> messages.SearchResponseModel:
         """Returns a list of the current user's private messages that match search criteria.
@@ -617,16 +684,20 @@ class MessagesCategory(BaseCategory):
 
         params = self.get_set_params(locals())
         response = await self.api.request("messages.search", params)
-        model = messages.SearchResponse
+        model = self.get_model(
+            {("extended",): messages.SearchExtendedResponse},
+            default=messages.SearchResponse,
+            params=params,
+        )
         return model(**response).response
 
     async def search_conversations(
         self,
-        q: Optional[str] = None,
-        count: Optional[int] = None,
-        extended: Optional[bool] = None,
-        fields: Optional[List[str]] = None,
-        group_id: Optional[int] = None,
+        q: typing.Optional[str] = None,
+        count: typing.Optional[int] = None,
+        extended: typing.Optional[bool] = None,
+        fields: typing.Optional[typing.List[str]] = None,
+        group_id: typing.Optional[int] = None,
         **kwargs
     ) -> messages.SearchConversationsResponseModel:
         """Returns a list of the current user's conversations that match search criteria.
@@ -639,37 +710,46 @@ class MessagesCategory(BaseCategory):
 
         params = self.get_set_params(locals())
         response = await self.api.request("messages.searchConversations", params)
-        model = messages.SearchConversationsResponse
+        model = self.get_model(
+            {("extended",): messages.SearchConversationsExtendedResponse},
+            default=messages.SearchConversationsResponse,
+            params=params,
+        )
         return model(**response).response
 
     async def send(
         self,
-        user_id: Optional[int] = None,
-        random_id: Optional[int] = None,
-        peer_id: Optional[int] = None,
-        domain: Optional[str] = None,
-        chat_id: Optional[int] = None,
-        user_ids: Optional[List[int]] = None,
-        message: Optional[str] = None,
-        lat: Optional[float] = None,
-        long: Optional[float] = None,
-        attachment: Optional[str] = None,
-        reply_to: Optional[int] = None,
-        forward_messages: Optional[List[int]] = None,
-        sticker_id: Optional[int] = None,
-        group_id: Optional[int] = None,
-        keyboard: Optional[str] = None,
-        payload: Optional[str] = None,
-        dont_parse_links: Optional[bool] = None,
-        disable_mentions: Optional[bool] = None,
-        intent: Optional[str] = None,
-        subscribe_id: Optional[int] = None,
+        user_id: typing.Optional[int] = None,
+        random_id: typing.Optional[int] = None,
+        peer_id: typing.Optional[int] = None,
+        peer_ids: typing.Optional[typing.List[int]] = None,
+        domain: typing.Optional[str] = None,
+        chat_id: typing.Optional[int] = None,
+        user_ids: typing.Optional[typing.List[int]] = None,
+        message: typing.Optional[str] = None,
+        lat: typing.Optional[int] = None,
+        long: typing.Optional[int] = None,
+        attachment: typing.Optional[str] = None,
+        reply_to: typing.Optional[int] = None,
+        forward_messages: typing.Optional[typing.List[int]] = None,
+        forward: typing.Optional[str] = None,
+        sticker_id: typing.Optional[int] = None,
+        group_id: typing.Optional[int] = None,
+        keyboard: typing.Optional[str] = None,
+        template: typing.Optional[str] = None,
+        payload: typing.Optional[str] = None,
+        content_source: typing.Optional[str] = None,
+        dont_parse_links: typing.Optional[bool] = None,
+        disable_mentions: typing.Optional[bool] = None,
+        intent: typing.Optional[str] = None,
+        subscribe_id: typing.Optional[int] = None,
         **kwargs
     ) -> messages.SendResponseModel:
         """Sends a message.
         :param user_id: User ID (by default — current user).
         :param random_id: Unique identifier to avoid resending the message.
         :param peer_id: Destination ID. "For user: 'User ID', e.g. '12345'. For chat: '2000000000' + 'chat_id', e.g. '2000000001'. For community: '- community ID', e.g. '-12345'. "
+        :param peer_ids: IDs of message recipients. (See peer_id)
         :param domain: User's short address (for example, 'illarionov').
         :param chat_id: ID of conversation the message will relate to.
         :param user_ids: IDs of message recipients (if new conversation shall be started).
@@ -679,10 +759,13 @@ class MessagesCategory(BaseCategory):
         :param attachment: (Required if 'message' is not set.) List of objects attached to the message, separated by commas, in the following format: "<owner_id>_<media_id>", '' — Type of media attachment: 'photo' — photo, 'video' — video, 'audio' — audio, 'doc' — document, 'wall' — wall post, '<owner_id>' — ID of the media attachment owner. '<media_id>' — media attachment ID. Example: "photo100172_166443618"
         :param reply_to:
         :param forward_messages: ID of forwarded messages, separated with a comma. Listed messages of the sender will be shown in the message body at the recipient's. Example: "123,431,544"
+        :param forward: JSON describing the forwarded message or reply
         :param sticker_id: Sticker id.
         :param group_id: Group ID (for group messages with group access token)
         :param keyboard:
+        :param template:
         :param payload:
+        :param content_source: JSON describing the content source in the message
         :param dont_parse_links:
         :param disable_mentions:
         :param intent:
@@ -691,11 +774,7 @@ class MessagesCategory(BaseCategory):
 
         params = self.get_set_params(locals())
         response = await self.api.request("messages.send", params)
-        model = self.get_model(
-            {("user_ids",): messages.SendUserIdsResponse},
-            default=messages.SendResponse,
-            params=params,
-        )
+        model = messages.SendResponse
         return model(**response).response
 
     async def send_message_event_answer(
@@ -703,7 +782,7 @@ class MessagesCategory(BaseCategory):
         event_id: str,
         user_id: int,
         peer_id: int,
-        event_data: Optional[str] = None,
+        event_data: typing.Optional[str] = None,
         **kwargs
     ) -> base.OkResponseModel:
         """messages.sendMessageEventAnswer method
@@ -720,10 +799,10 @@ class MessagesCategory(BaseCategory):
 
     async def set_activity(
         self,
-        user_id: Optional[int] = None,
-        type: Optional[str] = None,
-        peer_id: Optional[int] = None,
-        group_id: Optional[int] = None,
+        user_id: typing.Optional[int] = None,
+        type: typing.Optional[str] = None,
+        peer_id: typing.Optional[int] = None,
+        group_id: typing.Optional[int] = None,
         **kwargs
     ) -> base.OkResponseModel:
         """Changes the status of a user as typing in a conversation.
@@ -751,7 +830,7 @@ class MessagesCategory(BaseCategory):
         return model(**response).response
 
     async def unpin(
-        self, peer_id: int, group_id: Optional[int] = None, **kwargs
+        self, peer_id: int, group_id: typing.Optional[int] = None, **kwargs
     ) -> base.OkResponseModel:
         """messages.unpin method
         :param peer_id:
