@@ -1,10 +1,12 @@
-from vkbottle_types.responses import pages, base
-from typing import Optional, Any, List
+import typing
 from .base_category import BaseCategory
+from vkbottle_types.responses import base, pages
 
 
 class PagesCategory(BaseCategory):
-    async def clear_cache(self, url: str, **kwargs) -> base.OkResponseModel:
+    async def clear_cache(
+        self, url: str, **kwargs
+    ) -> base.OkResponseModel:
         """Allows to clear the cache of particular 'external' pages which may be attached to VK posts.
         :param url: Address of the page where you need to refesh the cached version
         """
@@ -16,19 +18,19 @@ class PagesCategory(BaseCategory):
 
     async def get(
         self,
-        owner_id: Optional[int] = None,
-        page_id: Optional[int] = None,
-        global_: Optional[bool] = None,
-        site_preview: Optional[bool] = None,
-        title: Optional[str] = None,
-        need_source: Optional[bool] = None,
-        need_html: Optional[bool] = None,
+        owner_id: typing.Optional[int] = None,
+        page_id: typing.Optional[int] = None,
+        _global: typing.Optional[bool] = None,
+        site_preview: typing.Optional[bool] = None,
+        title: typing.Optional[str] = None,
+        need_source: typing.Optional[bool] = None,
+        need_html: typing.Optional[bool] = None,
         **kwargs
     ) -> pages.GetResponseModel:
         """Returns information about a wiki page.
         :param owner_id: Page owner ID.
         :param page_id: Wiki page ID.
-        :param global_: '1' — to return information about a global wiki page
+        :param _global: '1' — to return information about a global wiki page
         :param site_preview: '1' — resulting wiki page is a preview for the attached link
         :param title: Wiki page title.
         :param need_source:
@@ -43,8 +45,8 @@ class PagesCategory(BaseCategory):
     async def get_history(
         self,
         page_id: int,
-        group_id: Optional[int] = None,
-        user_id: Optional[int] = None,
+        group_id: typing.Optional[int] = None,
+        user_id: typing.Optional[int] = None,
         **kwargs
     ) -> pages.GetHistoryResponseModel:
         """Returns a list of all previous versions of a wiki page.
@@ -59,7 +61,7 @@ class PagesCategory(BaseCategory):
         return model(**response).response
 
     async def get_titles(
-        self, group_id: Optional[int] = None, **kwargs
+        self, group_id: typing.Optional[int] = None, **kwargs
     ) -> pages.GetTitlesResponseModel:
         """Returns a list of wiki pages in a group.
         :param group_id: ID of the community that owns the wiki page.
@@ -73,9 +75,9 @@ class PagesCategory(BaseCategory):
     async def get_version(
         self,
         version_id: int,
-        group_id: Optional[int] = None,
-        user_id: Optional[int] = None,
-        need_html: Optional[bool] = None,
+        group_id: typing.Optional[int] = None,
+        user_id: typing.Optional[int] = None,
+        need_html: typing.Optional[bool] = None,
         **kwargs
     ) -> pages.GetVersionResponseModel:
         """Returns the text of one of the previous versions of a wiki page.
@@ -91,7 +93,7 @@ class PagesCategory(BaseCategory):
         return model(**response).response
 
     async def parse_wiki(
-        self, text: str, group_id: Optional[int] = None, **kwargs
+        self, text: str, group_id: typing.Optional[int] = None, **kwargs
     ) -> pages.ParseWikiResponseModel:
         """Returns HTML representation of the wiki markup.
         :param text: Text of the wiki page.
@@ -105,11 +107,11 @@ class PagesCategory(BaseCategory):
 
     async def save(
         self,
-        text: Optional[str] = None,
-        page_id: Optional[int] = None,
-        group_id: Optional[int] = None,
-        user_id: Optional[int] = None,
-        title: Optional[str] = None,
+        text: typing.Optional[str] = None,
+        page_id: typing.Optional[int] = None,
+        group_id: typing.Optional[int] = None,
+        user_id: typing.Optional[int] = None,
+        title: typing.Optional[str] = None,
         **kwargs
     ) -> pages.SaveResponseModel:
         """Saves the text of a wiki page.
@@ -128,10 +130,10 @@ class PagesCategory(BaseCategory):
     async def save_access(
         self,
         page_id: int,
-        group_id: Optional[int] = None,
-        user_id: Optional[int] = None,
-        view: Optional[int] = None,
-        edit: Optional[int] = None,
+        group_id: typing.Optional[int] = None,
+        user_id: typing.Optional[int] = None,
+        view: typing.Optional[int] = None,
+        edit: typing.Optional[int] = None,
         **kwargs
     ) -> pages.SaveAccessResponseModel:
         """Saves modified read and edit access settings for a wiki page.
