@@ -1,10 +1,12 @@
-from vkbottle_types.responses import stories, base
-from typing import Optional, Any, List
+import typing
 from .base_category import BaseCategory
+from vkbottle_types.responses import base, stories
 
 
 class StoriesCategory(BaseCategory):
-    async def ban_owner(self, owners_ids: List[int], **kwargs) -> base.OkResponseModel:
+    async def ban_owner(
+        self, owners_ids: typing.List[int], **kwargs
+    ) -> base.OkResponseModel:
         """Allows to hide stories from chosen sources from current user's feed.
         :param owners_ids: List of sources IDs
         """
@@ -15,11 +17,16 @@ class StoriesCategory(BaseCategory):
         return model(**response).response
 
     async def delete(
-        self, owner_id: int, story_id: int, **kwargs
+        self,
+        owner_id: typing.Optional[int] = None,
+        story_id: typing.Optional[int] = None,
+        stories: typing.Optional[typing.List[str]] = None,
+        **kwargs
     ) -> base.OkResponseModel:
         """Allows to delete story.
         :param owner_id: Story owner's ID. Current user id is used by default.
         :param story_id: Story ID.
+        :param stories:
         """
 
         params = self.get_set_params(locals())
@@ -29,9 +36,9 @@ class StoriesCategory(BaseCategory):
 
     async def get(
         self,
-        owner_id: Optional[int] = None,
-        extended: Optional[bool] = None,
-        fields: Optional[List[str]] = None,
+        owner_id: typing.Optional[int] = None,
+        extended: typing.Optional[bool] = None,
+        fields: typing.Optional[typing.List[str]] = None,
         **kwargs
     ) -> stories.GetV5113ResponseModel:
         """Returns stories available for current user.
@@ -47,8 +54,8 @@ class StoriesCategory(BaseCategory):
 
     async def get_banned(
         self,
-        extended: Optional[bool] = None,
-        fields: Optional[List[str]] = None,
+        extended: typing.Optional[bool] = None,
+        fields: typing.Optional[typing.List[str]] = None,
         **kwargs
     ) -> stories.GetBannedResponseModel:
         """Returns list of sources hidden from current user's feed.
@@ -67,13 +74,13 @@ class StoriesCategory(BaseCategory):
 
     async def get_by_id(
         self,
-        stories_: List[str],
-        extended: Optional[bool] = None,
-        fields: Optional[List[str]] = None,
+        stories: typing.List[str],
+        extended: typing.Optional[bool] = None,
+        fields: typing.Optional[typing.List[str]] = None,
         **kwargs
     ) -> stories.GetByIdResponseModel:
         """Returns story by its ID.
-        :param stories_: Stories IDs separated by commas. Use format {owner_id}+'_'+{story_id}, for example, 12345_54331.
+        :param stories: Stories IDs separated by commas. Use format {owner_id}+'_'+{story_id}, for example, 12345_54331.
         :param extended: '1' — to return additional fields for users and communities. Default value is 0.
         :param fields: Additional fields to return
         """
@@ -89,13 +96,13 @@ class StoriesCategory(BaseCategory):
 
     async def get_photo_upload_server(
         self,
-        add_to_news: Optional[bool] = None,
-        user_ids: Optional[List[int]] = None,
-        reply_to_story: Optional[str] = None,
-        link_text: Optional[str] = None,
-        link_url: Optional[str] = None,
-        group_id: Optional[int] = None,
-        clickable_stickers: Optional[str] = None,
+        add_to_news: typing.Optional[bool] = None,
+        user_ids: typing.Optional[typing.List[int]] = None,
+        reply_to_story: typing.Optional[str] = None,
+        link_text: typing.Optional[str] = None,
+        link_url: typing.Optional[str] = None,
+        group_id: typing.Optional[int] = None,
+        clickable_stickers: typing.Optional[str] = None,
         **kwargs
     ) -> stories.GetPhotoUploadServerResponseModel:
         """Returns URL for uploading a story with photo.
@@ -117,9 +124,9 @@ class StoriesCategory(BaseCategory):
         self,
         owner_id: int,
         story_id: int,
-        access_key: Optional[str] = None,
-        extended: Optional[bool] = None,
-        fields: Optional[List[str]] = None,
+        access_key: typing.Optional[str] = None,
+        extended: typing.Optional[bool] = None,
+        fields: typing.Optional[typing.List[str]] = None,
         **kwargs
     ) -> stories.GetV5113ResponseModel:
         """Returns replies to the story.
@@ -150,13 +157,13 @@ class StoriesCategory(BaseCategory):
 
     async def get_video_upload_server(
         self,
-        add_to_news: Optional[bool] = None,
-        user_ids: Optional[List[int]] = None,
-        reply_to_story: Optional[str] = None,
-        link_text: Optional[str] = None,
-        link_url: Optional[str] = None,
-        group_id: Optional[int] = None,
-        clickable_stickers: Optional[str] = None,
+        add_to_news: typing.Optional[bool] = None,
+        user_ids: typing.Optional[typing.List[int]] = None,
+        reply_to_story: typing.Optional[str] = None,
+        link_text: typing.Optional[str] = None,
+        link_url: typing.Optional[str] = None,
+        group_id: typing.Optional[int] = None,
+        clickable_stickers: typing.Optional[str] = None,
         **kwargs
     ) -> stories.GetVideoUploadServerResponseModel:
         """Allows to receive URL for uploading story with video.
@@ -178,9 +185,9 @@ class StoriesCategory(BaseCategory):
         self,
         owner_id: int,
         story_id: int,
-        count: Optional[int] = None,
-        offset: Optional[int] = None,
-        extended: Optional[bool] = None,
+        count: typing.Optional[int] = None,
+        offset: typing.Optional[int] = None,
+        extended: typing.Optional[bool] = None,
         **kwargs
     ) -> stories.GetViewersExtendedV5115ResponseModel:
         """Returns a list of story viewers.
@@ -201,7 +208,7 @@ class StoriesCategory(BaseCategory):
         return model(**response).response
 
     async def hide_all_replies(
-        self, owner_id: int, group_id: Optional[int] = None, **kwargs
+        self, owner_id: int, group_id: typing.Optional[int] = None, **kwargs
     ) -> base.OkResponseModel:
         """Hides all replies in the last 24 hours from the user to current user's stories.
         :param owner_id: ID of the user whose replies should be hidden.
@@ -226,17 +233,35 @@ class StoriesCategory(BaseCategory):
         model = base.OkResponse
         return model(**response).response
 
+    async def save(
+        self,
+        upload_results: typing.List[str],
+        extended: typing.Optional[bool] = None,
+        fields: typing.Optional[typing.List[str]] = None,
+        **kwargs
+    ) -> stories.SaveResponseModel:
+        """stories.save method
+        :param upload_results:
+        :param extended:
+        :param fields:
+        """
+
+        params = self.get_set_params(locals())
+        response = await self.api.request("stories.save", params)
+        model = stories.SaveResponse
+        return model(**response).response
+
     async def search(
         self,
-        q: Optional[str] = None,
-        place_id: Optional[int] = None,
-        latitude: Optional[float] = None,
-        longitude: Optional[float] = None,
-        radius: Optional[int] = None,
-        mentioned_id: Optional[int] = None,
-        count: Optional[int] = None,
-        extended: Optional[bool] = None,
-        fields: Optional[List[str]] = None,
+        q: typing.Optional[str] = None,
+        place_id: typing.Optional[int] = None,
+        latitude: typing.Optional[int] = None,
+        longitude: typing.Optional[int] = None,
+        radius: typing.Optional[int] = None,
+        mentioned_id: typing.Optional[int] = None,
+        count: typing.Optional[int] = None,
+        extended: typing.Optional[bool] = None,
+        fields: typing.Optional[typing.List[str]] = None,
         **kwargs
     ) -> stories.GetV5113ResponseModel:
         """stories.search method
@@ -256,8 +281,30 @@ class StoriesCategory(BaseCategory):
         model = stories.GetV5113Response
         return model(**response).response
 
+    async def send_interaction(
+        self,
+        access_key: str,
+        message: typing.Optional[str] = None,
+        is_broadcast: typing.Optional[bool] = None,
+        is_anonymous: typing.Optional[bool] = None,
+        unseen_marker: typing.Optional[bool] = None,
+        **kwargs
+    ) -> base.OkResponseModel:
+        """stories.sendInteraction method
+        :param access_key:
+        :param message:
+        :param is_broadcast:
+        :param is_anonymous:
+        :param unseen_marker:
+        """
+
+        params = self.get_set_params(locals())
+        response = await self.api.request("stories.sendInteraction", params)
+        model = base.OkResponse
+        return model(**response).response
+
     async def unban_owner(
-        self, owners_ids: List[int], **kwargs
+        self, owners_ids: typing.List[int], **kwargs
     ) -> base.OkResponseModel:
         """Allows to show stories from hidden sources in current user's feed.
         :param owners_ids: List of hidden sources to show stories from.
